@@ -346,7 +346,7 @@ void personal_gprs_mon_content_create (PersonalGprsMon *self)
 	
     gtk_widget_show_all (self->priv->homeWidget);
 	if (!self->priv->showResetDate) {
-		gtk_widget_hide_all (self->priv->resetBox);
+		gtk_widget_hide (self->priv->resetBox);
 	}
 	if (self->priv->compactMode) {
 		gtk_widget_hide (self->priv->titleBox);
